@@ -147,7 +147,9 @@ non_grid_int (PLFLT *x, PLFLT *y, PLFLT *z, int npts,
  * Create an interpolated Map
  * saving its WCS
  */
-int correct_mono_dar(int nb_spec, int *n_spaxels, SPAXEL **spaxels, float *slice, struct DAR *dar_t, int i_slice) {
+int correct_mono_dar(int nb_spec, int *n_spaxels, SPAXEL **spaxels, float *slice,
+                     struct DAR *dar_t, int i_slice)
+{
   int k,l;
   float *x,*y,*z;
   int n_tot;
@@ -211,6 +213,32 @@ int correct_mono_dar(int nb_spec, int *n_spaxels, SPAXEL **spaxels, float *slice
   return 0;
 }
 
+/*
+ * Strip working directory from incoming path, so that the LCL-filename
+ * limit is hit somewhat later. If the working directory is not part of
+ * the path, it will return the full path again.
+ */
+static char *strip_pwd_from_path(const char *path)
+{
+  char curpwd[PATH_MAX];
+  char *filename;
+
+  getcwd(curpwd, PATH_MAX);
+
+  filename = strstr(path, curpwd);
+  if (!filename) {
+     return (char *)path;
+  }
+
+  /* reset the pointer to after the path */
+  filename += strlen(curpwd);
+
+  /* and remove leading slashes */
+  while (filename[0] == '/') {
+     filename++;
+  }
+  return filename;
+}
 
 /*
  * Load the DAR correction
@@ -262,7 +290,8 @@ int load_dar(char* filename, struct DAR *dar, int npix, int n_groups) {
 /*
  * Save the DAR correction
  */
-int save_dar(char* filename, struct DAR *dar, int npix, int n_groups) {
+int save_dar(char* filename, struct DAR *dar, int npix, int n_groups)
+{
   FILE *fichero;
   int i,j;
 
@@ -283,18 +312,22 @@ int save_dar(char* filename, struct DAR *dar, int npix, int n_groups) {
 /*
  * Determine the DAR of a certain GROUP using Theoretical Values
  */
-int determine_dar(struct DAR dar, GROUP group, float start, float step, int npix) {
+int determine_dar(struct DAR dar, GROUP group, float start, float step, int npix)
+{
   int i;
   float l;
   float dr;
-  float z;
+  float z = 0;
   float dx0,dy0;
 
-  z=acos(1/group.airmass);
+  /* airmass values less than 1 don't make sense and for 0 this would crash */
+  if (group.airmass >= 1.0) {
+    z=acos(1/group.airmass);
+  }
   for (i=0;i<npix;i++) {
     l=start+step*i;
-    if ((group.pressure==group.pressure)&&(group.temperature==group.temperature)&&(group.rel_humidity==group.rel_humidity)) {
-      dar_l(&dr,l,group.pressure,group.temperature,group.rel_humidity,z);
+    if (group.pressure>0 && group.temperature>0 && group.rel_humidity>0 && z>0) {
+      dr = dar_l(l,group.pressure,group.temperature,group.rel_humidity,z);
       dar.dx[i]=dr*cos(group.parang*M_PI/180.);
       dar.dy[i]=dr*sin(group.parang*M_PI/180.);
     } else {
@@ -305,8 +338,8 @@ int determine_dar(struct DAR dar, GROUP group, float start, float step, int npix
   dx0=dar.dx[(int)(npix/2)];
   dy0=dar.dy[(int)(npix/2)];
   for (i=0;i<npix;i++) {
-    dar.dx[i]=(-1)*(dar.dx[i]-dx0);
-    dar.dy[i]=(-1)*(dar.dy[i]-dy0);
+    dar.dx[i]=dx0-dar.dx[i];
+    dar.dy[i]=dy0-dar.dy[i];
   }
   return 0;
 }
@@ -314,12 +347,12 @@ int determine_dar(struct DAR dar, GROUP group, float start, float step, int npix
 /*
  * Differential Atmospheric Refraction calculator
  */
-int dar_l(float *dr_out, float l, float p, float t, float f, float z) {
+float dar_l(float l, float p, float t, float f, float z)
+{
   float l0=5000;
   float a,b,c;
   float a0,b0,c0;
   float dr;
-  float out;
   float il,il0;
 
   f=p*f;
@@ -335,9 +368,7 @@ int dar_l(float *dr_out, float l, float p, float t, float f, float z) {
   c0=b0/(((0.0624-0.000680*il0)/(1+0.003661*t))*f);
 
   dr=c-c0;
-  out=206265.0*dr*tan(z);
-  *dr_out=out;
-  return 0;
+  return 206265.0*dr*tan(z);
 }
 
 /*
@@ -444,7 +475,7 @@ int save_PT_ascii(float *x, float *y, int *int_group, int n, GROUP *grupo, int n
  */
 int save_map(float* map_data, int nx, int ny, char* filename) {
   IMAGE2D image;
-  int npix[2];
+  long npix[2];
   double start[2];
   double step[2];
   int i,j;
@@ -477,7 +508,7 @@ int save_int_map(float* map_data, int nx, int ny, char* filename,
                  double crval1, double cdelt1, double crval2, double cdelt2)
 {
   IMAGE2D image;
-  int npix[2];
+  long npix[2];
   double start[2];
   double step[2];
   int i,j;
@@ -513,7 +544,7 @@ int save_int_map(float* map_data, int nx, int ny, char* filename,
 /*
  * Load Row Stacked Spectra (FITS file)
  */
-int load_rss(char *data_filename, char *pt_filename, int *out_nb_spec,
+int load_rss(char *rss_filename, char *pt_filename, int *out_nb_spec,
              int *out_npix, int **out_n_spaxels, SPAXEL ***out_spaxels,
              int **out_index_start, int **out_npts, float **out_raw_data,
              float **out_raw_noise, int *out_n_groups, GROUP **out_groups,
@@ -540,11 +571,14 @@ int load_rss(char *data_filename, char *pt_filename, int *out_nb_spec,
   char shape[20];
   float g_angle;
   int bitpix;
+  char *filename = strip_pwd_from_path(rss_filename);
+
+  printf("load_rss(): %s\n", filename);
 
   *dpix1 = 1.0; /* take the default from tk_e3d.c, reset below */
   *dpix2 = 1.0; /* take the default from tk_e3d.c, reset below */
 
-  open_frame(&image,data_filename,"I");
+  open_frame(&image,filename,"I");
   if (RD_desc(&image,"BITPIX",SHORT,1,&bitpix) < 0) {
     bitpix = -32;
   }
@@ -620,7 +654,7 @@ int load_rss(char *data_filename, char *pt_filename, int *out_nb_spec,
         if (j==0) {
           *dpix1 = size_x;
           *dpix2 = size_y;
-		  }
+        }
         groups[j].groupId=j+1;
         groups[j].size1=1.0*size_x;
         groups[j].size2=1.0*size_y;
@@ -692,8 +726,11 @@ int load_spectra(char *data_filename, int *out_nb_spec, int *out_npix,
   int bitpix;
   float x_min,dx;
   float y_min,dy;
+  char *filename = strip_pwd_from_path(data_filename);
 
-  open_frame(&image,data_filename,"I");
+  printf("load_spectra(): %s\n", filename);
+
+  open_frame(&image,filename,"I");
   if (RD_desc(&image,"BITPIX",SHORT,1,&bitpix) < 0) {
     bitpix = -32;
   }
@@ -796,7 +833,7 @@ int load_cube(char *cube_filename, int *out_nb_spec, int *out_npix,
               int *out_n_groups, GROUP **out_groups, double *out_start,
               double *out_step, float *dpix1, float *dpix2)
 {
-  IMAGE3D cube;
+  IMAGE3D *cube = calloc(1, sizeof(IMAGE3D));
   GROUP *groups;
   SPAXEL **spaxels;
   double start, step;
@@ -804,40 +841,57 @@ int load_cube(char *cube_filename, int *out_nb_spec, int *out_npix,
   float *raw_data,*raw_noise;
   char string[10];
   float crpix3,crpix2,crpix1, temp_float, x_min,dx,x0, y_min,dy,y0;
+  char *filename = strip_pwd_from_path(cube_filename);
+
+  printf("load_cube(): %s\n", filename);
 
   *dpix1 = 1.0;
   *dpix2 = 1.0;
 
-  open_cube(&cube,cube_filename,"I");
-  if (RD_desc(&cube,"CRPIX3",FLOAT,1,&crpix3) < 0) {
+  int rc = open_cube(cube,filename,"I");
+  if (rc) { /* bad return code, try again, reading a DATA extension this time */
+    print_msg("Could not load Cube, trying extension DATA (rc=%d)\n", rc);
+    char fn[FILENAME_MAX];
+    snprintf(fn, FILENAME_MAX, "%s[DATA]", filename);
+    rc = open_cube(cube, fn, "I");
+    if (rc) { /* bad again code, give up */
+      print_msg("Could not load \"%s\", either (rc=%d)\n", fn, rc);
+      free(cube);
+      return -1;
+    }
+  }
+  npix_p[0]=cube->nz;
+  npix_p[1]=cube->nx*cube->ny;
+
+  if (RD_desc(cube,"CRPIX3",FLOAT,1,&crpix3) < 0) {
     crpix3 = 0;
   }
-  if (RD_desc(&cube,"CRPIX1",FLOAT,1,&crpix1) < 0) {
+  if (RD_desc(cube,"CRPIX1",FLOAT,1,&crpix1) < 0) {
     crpix1 = 0;
   }
-  if (RD_desc(&cube,"CRPIX2",FLOAT,1,&crpix2) < 0) {
+  if (RD_desc(cube,"CRPIX2",FLOAT,1,&crpix2) < 0) {
     crpix2 = 0;
   }
-  if (RD_desc(&cube,"CRVAL3",DOUBLE,1,&start) < 0) {
+  if (RD_desc(cube,"CRVAL3",DOUBLE,1,&start) < 0) {
     start = 0;
   }
-  if (RD_desc(&cube,"CDELT3",DOUBLE,1,&step) < 0) {
+  if (RD_desc(cube,"CDELT3",DOUBLE,1,&step) < 0) {
     print_msg("FITS header CDELT3 missing (trying to use CD3_3 instead)!");
-    if (RD_desc(&cube,"CD3_3",DOUBLE,1,&step) < 0) {
+    if (RD_desc(cube,"CD3_3",DOUBLE,1,&step) < 0) {
       step = 1;
     }
   }
   start = start - step*crpix3;
-  if (RD_desc(&cube,"CRVAL1",FLOAT,1,&x_min) < 0) {
+  if (RD_desc(cube,"CRVAL1",FLOAT,1,&x_min) < 0) {
     x_min = 0;
   }
-  if (RD_desc(&cube,"CDELT1",FLOAT,1,&dx) < 0) {
+  if (RD_desc(cube,"CDELT1",FLOAT,1,&dx) < 0) {
     print_msg("FITS header CDELT1 missing (trying to use CD1_1 instead)!");
-    if (RD_desc(&cube,"CD1_1",FLOAT,1,&dx) < 0) {
+    if (RD_desc(cube,"CD1_1",FLOAT,1,&dx) < 0) {
       dx = 1;
     }
   } else {
-    if (RD_desc(&cube,"CUNIT1",CHAR,6,string) > 0) {
+    if (RD_desc(cube,"CUNIT1",CHAR,6,string) > 0) {
       if (!strncmp(string,"deg",3) || !strncmp(string,"DEG",3)) {
         /* Greisen & Calabretta say that this should be case sensitive but *
          * not everybody seems to honor that (SINFONI)                     */
@@ -854,16 +908,16 @@ int load_cube(char *cube_filename, int *out_nb_spec, int *out_npix,
       /* no CUNIT1 keyword, assume arcseconds, do nothing */
     }
   }
-  if (RD_desc(&cube,"CRVAL2",FLOAT,1,&y_min) < 0) {
+  if (RD_desc(cube,"CRVAL2",FLOAT,1,&y_min) < 0) {
     y_min = 0;
   }
-  if (RD_desc(&cube,"CDELT2",FLOAT,1,&dy) < 0) {
+  if (RD_desc(cube,"CDELT2",FLOAT,1,&dy) < 0) {
     print_msg("FITS header CDELT2 missing (trying to use CD2_2 instead)!");
-    if (RD_desc(&cube,"CD2_2",FLOAT,1,&dy) < 0) {
+    if (RD_desc(cube,"CD2_2",FLOAT,1,&dy) < 0) {
       dy = 1;
     }
   } else {
-    if (RD_desc(&cube,"CUNIT2",CHAR,6,string) > 0) {
+    if (RD_desc(cube,"CUNIT2",CHAR,6,string) > 0) {
       if (!strncmp(string,"deg",3) || !strncmp(string,"DEG",3)) {
         /* Greisen & Calabretta say that this should be case sensitive but *
          * not everybody seems to honor that (SINFONI)                     */
@@ -882,20 +936,14 @@ int load_cube(char *cube_filename, int *out_nb_spec, int *out_npix,
   }
 
   /* determine the lower left corner */
-#ifdef DEBUG_e3d_load
-  printf("%f %f %f, %f %f, %f %f, %f\n", crpix1, crpix2, crpix3, dx, dy, x_min, y_min, start);
-#endif
-  x0=dx*(1-crpix1);
+  x0=dx*(crpix1-1);
   y0=dy*(crpix2-1);
+#ifdef DEBUG_e3d_load
+  printf("%f %f %f, %f %f, %f %f, %f => %f/%f\n",
+         crpix1, crpix2, crpix3, dx, dy, x_min, y_min, start, x0, y0);
+#endif
   *dpix1 = dx;
   *dpix2 = dy;
-  npix_p[0]=cube.nz;
-  npix_p[1]=cube.nx*cube.ny;
-
-  if (!(npix_p[1] > 0) || !(npix_p[0] > 0)) {
-    print_msg("Could not load Cube\n");
-    return -1;
-  }
 
   /*
    * Creating GROUP
@@ -932,31 +980,32 @@ int load_cube(char *cube_filename, int *out_nb_spec, int *out_npix,
   raw_data = (float *)malloc(npix_p[0]*npix_p[1]*sizeof(float));
   raw_noise = (float *)malloc(npix_p[0]*npix_p[1]*sizeof(float));
   specid_counter=1;
-  for (j=0;j<cube.nx;j++) {
-    for (i=0;i<cube.ny;i++) {
-      spaxels[j*cube.ny+i][0].specId=specid_counter;
-      spaxels[j*cube.ny+i][0].xpos=x0+dx*j;
-      spaxels[j*cube.ny+i][0].ypos=y0+dy*i;
-      spaxels[j*cube.ny+i][0].group=1;
+  for (j=0;j<cube->nx;j++) {
+    for (i=0;i<cube->ny;i++) {
+      spaxels[j*cube->ny+i][0].specId=specid_counter;
+      spaxels[j*cube->ny+i][0].xpos=x0+dx*j;
+      spaxels[j*cube->ny+i][0].ypos=y0+dy*i;
+      spaxels[j*cube->ny+i][0].group=1;
       specid_counter++;
 #ifdef DEBUG_e3d_load
       printf("%d/%d, %d, %f,%f/%f,%f, %f/%f\n", i,j, specid_counter, x0, dx, y0, dy,
-             spaxels[j*cube.ny+i][0].xpos, spaxels[j*cube.ny+i][0].ypos);
+             spaxels[j*cube->ny+i][0].xpos, spaxels[j*cube->ny+i][0].ypos);
 #endif
     }
   }
 
-  for (i=0;i<cube.nx;i++) {
-    for (j=0;j<cube.ny;j++) {
-      for (k=0;k<cube.nz;k++) {
-        temp_float = (float)RD_cube(&cube,i,j,k);
-        raw_data[k+(j+(cube.nx-i-1)*cube.ny)*cube.nz] = temp_float;
+  for (i=0;i<cube->nx;i++) {
+    for (j=0;j<cube->ny;j++) {
+      for (k=0;k<cube->nz;k++) {
+        temp_float = (float)RD_cube(cube,i,j,k);
+        raw_data[k+(j+i*cube->ny)*cube->nz] = temp_float;
         /* XXX /1 should be really /gain for the noise */
-        raw_noise[k+(j+(cube.nx-i-1)*cube.ny)*cube.nz] = sqrt(temp_float/1);
+        raw_noise[k+(j+i*cube->ny)*cube->nz] = sqrt(temp_float/1);
       }
     }
   }
-  close_cube(&cube);
+  close_cube(cube);
+  free(cube);
 
   /*
    * We present the output data
@@ -998,8 +1047,11 @@ int load_map(char *map_filename, int *out_nb_spec, int *out_npix,
   float x_min,dx;
   float y_min,dy;
   int nx,ny;
+  char *filename = strip_pwd_from_path(map_filename);
 
-  open_frame(&map,map_filename,"I");
+  printf("load_map(): %s\n", filename);
+
+  open_frame(&map,filename,"I");
   if (RD_desc(&map,"CRVAL1",DOUBLE,1,&y_min) < 0) {
     y_min=0.0;
   }
@@ -1092,10 +1144,11 @@ int load_map(char *map_filename, int *out_nb_spec, int *out_npix,
 
 int save_raw(float* map_data, int nx, int ny, char* filename, double start_w, double step_w) {
   IMAGE2D image;
-  int npix[2];
+  long npix[2];
   double start[2];
   double step[2];
   int i,j;
+
   npix[0]=nx;
   npix[1]=ny;
   start[0]=0.0;
@@ -1214,7 +1267,7 @@ int save_cube(int nb_spec, int npix_p, int *n_spaxels, SPAXEL **spaxels,
   float *xo,*yo,**zo;
   IMAGE3D cube;
   double start[3],step[3];
-  int npix[3];
+  long npix[3];
 
 #ifdef DEBUG_e3d_save
   printf("%f/%f %f %f %f %f %f %f\n", dpix1,dpix2, x_max, x_min, y_max, y_min,
@@ -1239,9 +1292,12 @@ int save_cube(int nb_spec, int npix_p, int *n_spaxels, SPAXEL **spaxels,
   xo = (float *)calloc(nx,sizeof(float));
   yo = (float *)calloc(ny,sizeof(float));
   zo = (PLFLT **)calloc(nx,sizeof(PLFLT*));
-  for (i = 0; i < nx; i++) zo[i] = (PLFLT *)calloc(ny,sizeof(PLFLT));
-  for (i=0;i<nx;i++) xo[i]=x_min+step[0]*i;
-  for (j=0;j<ny;j++) yo[j]=y_min+step[1]*j;
+  for (i=0;i<nx;i++) {
+    zo[i]=(PLFLT *)calloc(ny,sizeof(PLFLT));
+    xo[i]=x_min+step[0]*i;
+  }
+  for (j=0;j<ny;j++)
+    yo[j]=y_min+step[1]*j;
 
   /*
    * We count the number of points included in the SPAXELS array
@@ -1321,7 +1377,8 @@ void spec_plot(float* data, float datamin, float datamax, int npix, double start
 /*
  * Plot a certain section of a spectrum
  */
-void spec_plot_range(float* data, float datamin, float datamax, int npix_w1, int npix_w2, double start_w, double delta_w, int clean)
+void spec_plot_range(float* data, float datamin, float datamax, int npix_w1,
+                     int npix_w2, double start_w, double delta_w, int clean)
 {
   float *x,*y;
   int i;
@@ -1350,9 +1407,12 @@ void spec_plot_range(float* data, float datamin, float datamax, int npix_w1, int
 }
 
 /*
- * Fit a single line to a section of an spectra.
+ * Fit a single line to a section of a spectrum
  */
-float fit_single_line(float *data, float *noise, float datamin, float datamax, int npix_w1, int npix_w2, double start_w, double delta_w, int clean, float a[4], float d_a[4], int ia[4], float chisq_cont)
+float fit_single_line(float *data, float *noise, float datamin, float datamax,
+                      int npix_w1, int npix_w2, double start_w, double delta_w,
+                      int clean, float a[4], float d_a[4], int ia[4],
+                      float chisq_cont)
 {
   float *x,*y,*s_y,*y_mod,*y_res,y_tmp;
   int i,ndat;
@@ -1698,10 +1758,8 @@ int ask_e3d_info(E3D_file *e3d_frame, int **n_spaxels,
                  GROUP **groups)
 {
   E3D_file e3d_temp;
-  int *n_spaxels_temp;
+  int *n_spaxels_temp = NULL, *index_start_temp = NULL, *npts_temp = NULL;
   SPAXEL **spaxels_temp;
-  int *index_start_temp;
-  int *npts_temp;
   GROUP *groups_temp;
   int nb_spec, npix;
   float delta_w;
@@ -2344,7 +2402,7 @@ int server() {
  * A basic function that load an E3D file and the
  * basic parameters needed to handle the image
  *********************************************/
-int load_e3d(char *filename, E3D_file *e3d_frame, int **n_spaxels,
+int load_e3d(char *e3d_filename, E3D_file *e3d_frame, int **n_spaxels,
              SPAXEL ***spaxels, int **index_start, int **npts,
              float **raw_data, float **raw_noise)
 {
@@ -2360,6 +2418,9 @@ int load_e3d(char *filename, E3D_file *e3d_frame, int **n_spaxels,
   int *nol_temp, max_npts;
   float start_w,end_w,delta_w;
   SPECTRUM signal;
+  char *filename = strip_pwd_from_path(e3d_filename);
+
+  printf("load_e3d(): %s\n", filename);
 
   open_E3D_frame(&e3d_temp,filename,"I");
   nb_spec=e3d_temp.nbspec;
@@ -2438,7 +2499,7 @@ int load_e3d(char *filename, E3D_file *e3d_frame, int **n_spaxels,
 /************************
  * We read the Euro3D file, without saving the complete file.
  ************************/
-int load_e3d_groups(char *filename, int *n_groups, GROUP **groups,
+int load_e3d_groups(char *e3d_filename, int *n_groups, GROUP **groups,
                     float *common_parameters, int *nb_spec_out,
                     int **n_spaxels, SPAXEL ***spaxels, int **index_start,
                     int **npts, float **raw_data, float **raw_noise)
@@ -2456,6 +2517,9 @@ int load_e3d_groups(char *filename, int *n_groups, GROUP **groups,
   int *nol_temp, max_npts;
   float start_w,end_w,delta_w;
   SPECTRUM signal;
+  char *filename = strip_pwd_from_path(e3d_filename);
+
+  printf("load_e3d_groups(): %s\n", filename);
 
   open_E3D_frame(&e3d_temp,filename,"I");
   nb_spec=e3d_temp.nbspec;
@@ -2540,13 +2604,16 @@ int load_e3d_groups(char *filename, int *n_groups, GROUP **groups,
 /*****************************
  * We read only the common information
  *****************************/
-int load_e3d_only_groups(char *filename, int *n_groups, GROUP **groups,
+int load_e3d_only_groups(char *e3d_filename, int *n_groups, GROUP **groups,
                          float *common_parameters, int *nb_spec_out)
 {
   E3D_file e3d_temp;
   int i;
   int nb_spec, npix;
   float start_w,end_w,delta_w;
+  char *filename = strip_pwd_from_path(e3d_filename);
+
+  printf("load_e3d_only_groups(): %s\n", filename);
 
   open_E3D_frame(&e3d_temp,filename,"I");
   nb_spec=e3d_temp.nbspec;
@@ -2582,7 +2649,7 @@ int load_e3d_only_groups(char *filename, int *n_groups, GROUP **groups,
 /*
  * We only read the data...
  */
-int load_e3d_only_data(char *filename, int nb_spec, int npix,
+int load_e3d_only_data(char *e3d_filename, int nb_spec, int npix,
                        int *n_spaxels_temp, SPAXEL ***spaxels,
                        int *index_start_temp, int *npts_temp,
                        float *raw_data_temp, float *raw_noise_temp)
@@ -2594,6 +2661,9 @@ int load_e3d_only_data(char *filename, int nb_spec, int npix,
   int specId;
   int *nol_temp, max_npts;
   float start_w;
+  char *filename = strip_pwd_from_path(e3d_filename);
+
+  printf("load_e3d_only_data(): %s\n", filename);
 
   open_E3D_frame(&e3d_temp,filename,"I");
   nol_temp = (int *) calloc(nb_spec, sizeof(int));
@@ -3387,8 +3457,8 @@ void plot_spaxel(int color_index, float x_c, float y_c, GROUP group,
   float xp[6],yp[6];
   float x[6],y[6];
 
-  size1=(float)1.05*group.size1;
-  size2=(float)1.05*group.size2;
+  size1=(float)group.size1;
+  size2=(float)group.size2;
   if (size1==0.0) size1=0.30;
   angle=((float)group.angle)/180*M_PI;
 
@@ -3405,7 +3475,7 @@ void plot_spaxel(int color_index, float x_c, float y_c, GROUP group,
       xp[0]=-size1; yp[0]=-size1;
       xp[1]=size1; yp[1]=-size1;
       xp[2]=size1; yp[2]=size1;
-          xp[3]=-size1; yp[3]=size1;
+      xp[3]=-size1; yp[3]=size1;
       for (i=0;i<4;i++) {
         x[i]=x_c+xp[i]*cos(angle)-yp[i]*sin(angle);
         y[i]=y_c+xp[i]*sin(angle)+yp[i]*cos(angle);
