@@ -185,7 +185,7 @@ int main(int argc, char **argv)
   char input_filename[80];
   float min,max,min_i,max_i;
   int naxes[2];
-  int npix_int;
+  long npix_long;
   double start_ww,end_ww;
   float start_w, end_w, delta_w;
   /* PGPLOT needed varibles */
@@ -287,12 +287,12 @@ int main(int argc, char **argv)
   fflush(stdout);
 
   printf("Reading common parameters\n");
-  get_common_param(&e3d_image,&npix_int,&start_ww,&end_ww);        
+  get_common_param(&e3d_image,&npix_long,&start_ww,&end_ww);
   start_w=(float)start_ww;
   end_w=(float)end_ww;
-  printf("%d,%f,%f\n",npix_int,start_w,end_w);
+  printf("%ld,%f,%f\n",npix_long,start_w,end_w);
 
-  delta_w=(end_w-start_w)/npix_int;
+  delta_w=(end_w-start_w)/npix_long;
 
   get_spectra_ID(&e3d_image,nol);
   printf("Reading Euro3D values spectrum by spectrum ...");
@@ -332,9 +332,9 @@ int main(int argc, char **argv)
       npix=signal.npts;
       naxes[0]=npix;
       raw_data = (float *)malloc((npix*nb_spec)*sizeof(float));  
-      if (npix_int!=npix) {
+      if (npix_long!=npix) {
         printf("There is some error in the determination of the number of pixels\n");
-        printf("npix=%d npix_int=%d\n",npix,npix_int);
+        printf("npix=%d npix_long=%ld\n",npix,npix_long);
       }
     }
     for (j=0;j<signal.npts;j++) {
@@ -368,10 +368,10 @@ int main(int argc, char **argv)
    * We open the devices we are going to use.
    */
   id1=cpgopen("/xwin");
-  printf("F=%f\n",(float)nb_spec/(float)npix_int);
+  printf("F=%f\n",(float)nb_spec/(float)npix_long);
   window_size=floor((float)nb_spec/1024);
   if (window_size>10) window_size=10;
-  window_aspect=0.7*(float)nb_spec/(float)npix_int;
+  window_aspect=0.7*(float)nb_spec/(float)npix_long;
   //        if (window_aspect<0.5) window_aspect=0.5;
   //        if (window_aspect>1.0) {
     //window_size=floor((float)window_size/(0.5*window_aspect));
