@@ -176,9 +176,9 @@ int main(int argc, char **argv)
   /* Euro3D variables */
   int specId, i,j, npix, nb_spec, nfib;
   /* General variables */
-  float min,max,min_i,max_i;
+  float min,max,min_i = 0.,max_i = 0.;
   int naxes[2];
-  int npix_int;
+  long npix_long;
   double start_w, end_w, delta_w;
   /* PGPLOT needed varibles */
   char answer_now;
@@ -203,9 +203,9 @@ int main(int argc, char **argv)
 
   start_w=e3d_image.common_parameters[0];
   end_w=e3d_image.common_parameters[1];
-  npix_int=e3d_image.common_parameters[2];
-  delta_w=(end_w-start_w)/npix_int;
-  npix=npix_int;
+  npix_long=e3d_image.common_parameters[2];
+  delta_w=(end_w-start_w)/npix_long;
+  npix=npix_long;
   nb_spec=e3d_image.nbspec;
   n_groups=e3d_image.ngroups;
 
@@ -233,7 +233,7 @@ int main(int argc, char **argv)
       if (y_min>spaxels[specId-1][j].ypos) y_min=spaxels[specId-1][j].ypos;
       if (y_max<spaxels[specId-1][j].ypos) y_max=spaxels[specId-1][j].ypos;
     }
-    for (j=0;j<npix_int;j++) {
+    for (j=0;j<npix_long;j++) {
       if (min>raw_data[j+(specId-1)*npix])
         min=raw_data[j+(specId-1)*npix];
       if (max<raw_data[j+(specId-1)*npix])
@@ -246,7 +246,7 @@ int main(int argc, char **argv)
     max=max_i;
   printf("min=%f,max=%f\n",min,max);
 
-  naxes[0]=npix_int;
+  naxes[0]=npix_long;
   naxes[1]=nb_spec;
   id1=cpgopen("/xwin");
   cpgpap(10,0.5);
