@@ -176,7 +176,7 @@ int main(int argc, char **argv)
   char input_filename[80];
   float min,max,min_i,max_i;
   int naxes[2];
-  int npix_int;
+  long npix_long;
   double start_w, end_w, delta_w;
   /* PGPLOT needed varibles */
 
@@ -275,9 +275,9 @@ int main(int argc, char **argv)
   npts = (int *)malloc(nb_spec*sizeof(int));
 
   printf("Reading common parameters\n");
-  get_common_param(&e3d_image,&npix_int,&start_w,&end_w);
-  printf("%d,%f,%f\n",npix_int,start_w,end_w);
-  delta_w=(end_w-start_w)/npix_int;
+  get_common_param(&e3d_image,&npix_long,&start_w,&end_w);
+  printf("%ld,%f,%f\n",npix_long,start_w,end_w);
+  delta_w=(end_w-start_w)/npix_long;
 
   get_spectra_ID(&e3d_image,nol);
   printf("Reading Euro3D values spectrum by spectrum ...\n");
@@ -326,9 +326,9 @@ int main(int argc, char **argv)
   npix=max_npts;
   naxes[0]=npix;
   raw_data = (float *)malloc((npix*nb_spec)*sizeof(float));
-  if (npix_int!=npix) {
+  if (npix_long!=npix) {
     printf("There is some error in the determination of the number of pixels\n");
-    printf("npix=%d!=%d\n",npix,npix_int);
+    printf("npix=%d!=%ld\n",npix,npix_long);
   }
   for (specId=1;specId<=nb_spec;specId++) {
     for (j=0;j<max_npts;j++) {
