@@ -224,7 +224,7 @@ void main(int argc, char **argv)
 	int error=0;
 	float min,max,mean,sigma,min_i,max_i;
 	int naxes[2],daxes[2];
-	int npix_int;
+	long npix_long;
 	double start_w, end_w, delta_w;
 	
 	/* PGPLOT needed varibles */
@@ -341,9 +341,9 @@ void main(int argc, char **argv)
 	fflush(stdout);
 
 	printf("Reading common parameters\n");
-	get_common_param(&e3d_image,&npix_int,&start_w,&end_w);	
-	printf("%d,%f,%f\n",npix_int,start_w,end_w);
-	delta_w=(end_w-start_w)/npix_int;
+	get_common_param(&e3d_image,&npix_long,&start_w,&end_w);
+	printf("%ld,%f,%f\n",npix_long,start_w,end_w);
+	delta_w=(end_w-start_w)/npix_long;
 
 	get_spectra_ID(&e3d_image,nol);
 	printf("Reading Euro3D values spectrum by spectrum ...");
@@ -383,9 +383,9 @@ void main(int argc, char **argv)
 	    npix=signal.npts;
 	    naxes[0]=npix;
 	    raw_data = (float *)malloc((npix*nb_spec)*sizeof(float));  
-	    if (npix_int!=npix) {
+	    if (npix_long!=npix) {
 	      printf("There is some error in the determination of the number of pixels\n");
-	      printf("npix=%d!=%d\n",npix,npix_int);
+	      printf("npix=%d!=%ld\n",npix,npix_long);
 	    }
 	  }
 	  for (j=0;j<signal.npts;j++) {
@@ -425,10 +425,10 @@ void main(int argc, char **argv)
 	 * We open the devices we are going to use.
 	 */
 	id1=cpgopen("/xwin");
-	printf("F=%f\n",(float)nb_spec/(float)npix_int);
+	printf("F=%f\n",(float)nb_spec/(float)npix_long);
 	window_size=3*floor((float)nb_spec/1024);
 	if (window_size>10) window_size=10;
-	window_aspect=0.7*(float)nb_spec/(float)npix_int;
+	window_aspect=0.7*(float)nb_spec/(float)npix_long;
 	//	if (window_aspect<0.5) window_aspect=0.5;
 	//	if (window_aspect>1.0) {
 	  //window_size=floor((float)window_size/(0.5*window_aspect));
